Authors
=======


Lead
----

- Peter Driscoll, patardriscoll@gmail.com, `pvd232@github <https://github.com/pvd232/pushjack_http2_mod>`_

Contributors
------------

- Derrick Gilland, dgilland@gmail.com, `dgilland@github <https://github.com/dgilland>`_
- Brad Montgomery, `bradmontgomery@github <https://github.com/bradmontgomery>`_
- Julius Seporaitis, `seporaitis@github <https://github.com/seporaitis>`_
- Ahmed Khedr, `aakhedr@github <https://github.com/aakhedr>`_
- Jakub Kleň, `kukosk@github <https://github.com/kukosk>`_
- Lukas Anzinger, `Lukas0907@github <https://github.com/Lukas0907>`_
